
package Date::Lite;

use strict;
use warnings 'all';

our $VERSION = '0.000_01';

1;# return true:

=pod

=head1 NAME

Date::Lite - Simple date utility objects and functions.

=head1 SYNOPSIS

  # TBD

=head1 DESCRIPTION

TBD

=head1 AUTHOR

John Drago <jdrago_999@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright 2010 John Drago all rights reserved.

This software is Free software and may be used and redistributed under the same terms
as perl itself, any version.

=cut

